yakumo.neutron.v2.port.Resource

Package yakumo :: Package neutron :: Package v2 :: Module port :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for ports in Networking V2 API

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, device=`'``__UNDEF__``'`, device_owner=`'``__UNDEF__``'`, allowed_address_pairs=`'``__UNDEF__``'`, mac_address=`'``__UNDEF__``'`, fixed_ips=`'``__UNDEF__``'`, security_groups=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) update properties of a port | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, device=`'``__UNDEF__``'`, device_owner=`'``__UNDEF__``'`, allowed_address_pairs=`'``__UNDEF__``'`, mac_address=`'``__UNDEF__``'`, fixed_ips=`'``__UNDEF__``'`, security_groups=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
update properties of a port Parameters: `name` (str) - Port name `network` (yakumo.neutron.v2.network.Resource) - Network `project` (yakumo.project.Resource) - Project `device` (Resource object) - Attached device (server, router, floating IP, ...) `device_owner` (str) - Device owner `allowed_address_pairs` (str) - Allowed address pairs `mac_address` (str) - MAC address `fixed_ips` ([{'ip_address': str, 'subnet': yakumo.subnet.Resource}]) - List of dictionary with fixed IP and subnet `security_groups` (str) - Security groups `is_enabled` (bool) - Whether the port is enabled Returns: None Overrides: base.Resource.update